@@ -1125,11 +1125,7 @@ module.exports = {
 		"11.4.6",
 		"11.4.7",
 		"11.4.8",
-		"11.4.9",
-		"11.4.10",
-		"11.4.11",
-		"11.4.12",
-		"11.5.0"
+		"11.4.9"
 	],
 	"89.0.4328.0": [
 		"12.0.0-beta.1",
@@ -1228,19 +1224,7 @@ module.exports = {
 		"12.0.10",
 		"12.0.11",
 		"12.0.12",
-		"12.0.13",
-		"12.0.14",
-		"12.0.15",
-		"12.0.16",
-		"12.0.17",
-		"12.0.18",
-		"12.1.0",
-		"12.1.1",
-		"12.1.2",
-		"12.2.0",
-		"12.2.1",
-		"12.2.2",
-		"12.2.3"
+		"12.0.13"
 	],
 	"90.0.4402.0": [
 		"13.0.0-beta.2",
@@ -1355,29 +1339,6 @@ module.exports = {
 		"13.1.3",
 		"13.1.4"
 	],
-	"91.0.4472.124": [
-		"13.1.5",
-		"13.1.6",
-		"13.1.7"
-	],
-	"91.0.4472.164": [
-		"13.1.8",
-		"13.1.9",
-		"13.2.0",
-		"13.2.1",
-		"13.2.2",
-		"13.2.3",
-		"13.3.0",
-		"13.4.0",
-		"13.5.0",
-		"13.5.1",
-		"13.5.2",
-		"13.6.0",
-		"13.6.1",
-		"13.6.2",
-		"13.6.3",
-		"13.6.6"
-	],
 	"92.0.4511.0": [
 		"14.0.0-beta.1",
 		"14.0.0-beta.2",
@@ -1411,48 +1372,6 @@ module.exports = {
 		"15.0.0-nightly.20210621",
 		"15.0.0-nightly.20210622"
 	],
-	"93.0.4557.4": [
-		"14.0.0-beta.11",
-		"14.0.0-beta.12"
-	],
-	"93.0.4566.0": [
-		"14.0.0-beta.13",
-		"14.0.0-beta.14",
-		"14.0.0-beta.15",
-		"14.0.0-beta.16",
-		"14.0.0-beta.17",
-		"15.0.0-alpha.1",
-		"15.0.0-alpha.2",
-		"15.0.0-nightly.20210706",
-		"15.0.0-nightly.20210707",
-		"15.0.0-nightly.20210708",
-		"15.0.0-nightly.20210709",
-		"15.0.0-nightly.20210712",
-		"15.0.0-nightly.20210713",
-		"15.0.0-nightly.20210714",
-		"15.0.0-nightly.20210715",
-		"15.0.0-nightly.20210716",
-		"15.0.0-nightly.20210719",
-		"15.0.0-nightly.20210720",
-		"15.0.0-nightly.20210721",
-		"16.0.0-nightly.20210722",
-		"16.0.0-nightly.20210723",
-		"16.0.0-nightly.20210726"
-	],
-	"93.0.4577.15": [
-		"14.0.0-beta.18",
-		"14.0.0-beta.19",
-		"14.0.0-beta.20",
-		"14.0.0-beta.21"
-	],
-	"93.0.4577.25": [
-		"14.0.0-beta.22",
-		"14.0.0-beta.23"
-	],
-	"93.0.4577.51": [
-		"14.0.0-beta.24",
-		"14.0.0-beta.25"
-	],
 	"92.0.4475.0": [
 		"14.0.0-nightly.20210426",
 		"14.0.0-nightly.20210427"
@@ -1480,66 +1399,6 @@ module.exports = {
 		"14.0.0-nightly.20210518",
 		"14.0.0-nightly.20210519"
 	],
-	"93.0.4577.58": [
-		"14.0.0"
-	],
-	"93.0.4577.63": [
-		"14.0.1"
-	],
-	"93.0.4577.82": [
-		"14.0.2",
-		"14.1.0",
-		"14.1.1",
-		"14.2.0",
-		"14.2.1",
-		"14.2.2",
-		"14.2.3"
-	],
-	"94.0.4584.0": [
-		"15.0.0-alpha.3",
-		"15.0.0-alpha.4",
-		"15.0.0-alpha.5",
-		"15.0.0-alpha.6",
-		"16.0.0-nightly.20210727",
-		"16.0.0-nightly.20210728",
-		"16.0.0-nightly.20210729",
-		"16.0.0-nightly.20210730",
-		"16.0.0-nightly.20210802",
-		"16.0.0-nightly.20210803",
-		"16.0.0-nightly.20210804",
-		"16.0.0-nightly.20210805",
-		"16.0.0-nightly.20210806",
-		"16.0.0-nightly.20210809",
-		"16.0.0-nightly.20210810",
-		"16.0.0-nightly.20210811"
-	],
-	"94.0.4590.2": [
-		"15.0.0-alpha.7",
-		"15.0.0-alpha.8",
-		"15.0.0-alpha.9",
-		"16.0.0-nightly.20210812",
-		"16.0.0-nightly.20210813",
-		"16.0.0-nightly.20210816",
-		"16.0.0-nightly.20210817",
-		"16.0.0-nightly.20210818",
-		"16.0.0-nightly.20210819",
-		"16.0.0-nightly.20210820",
-		"16.0.0-nightly.20210823"
-	],
-	"94.0.4606.12": [
-		"15.0.0-alpha.10"
-	],
-	"94.0.4606.20": [
-		"15.0.0-beta.1",
-		"15.0.0-beta.2"
-	],
-	"94.0.4606.31": [
-		"15.0.0-beta.3",
-		"15.0.0-beta.4",
-		"15.0.0-beta.5",
-		"15.0.0-beta.6",
-		"15.0.0-beta.7"
-	],
 	"93.0.4530.0": [
 		"15.0.0-nightly.20210603",
 		"15.0.0-nightly.20210604"
@@ -1555,176 +1414,5 @@ module.exports = {
 		"15.0.0-nightly.20210625",
 		"15.0.0-nightly.20210628",
 		"15.0.0-nightly.20210629"
-	],
-	"93.0.4558.0": [
-		"15.0.0-nightly.20210630",
-		"15.0.0-nightly.20210701",
-		"15.0.0-nightly.20210702",
-		"15.0.0-nightly.20210705"
-	],
-	"94.0.4606.51": [
-		"15.0.0"
-	],
-	"94.0.4606.61": [
-		"15.1.0",
-		"15.1.1"
-	],
-	"94.0.4606.71": [
-		"15.1.2"
-	],
-	"94.0.4606.81": [
-		"15.2.0",
-		"15.3.0",
-		"15.3.1",
-		"15.3.2",
-		"15.3.3",
-		"15.3.4"
-	],
-	"95.0.4629.0": [
-		"16.0.0-alpha.1",
-		"16.0.0-alpha.2",
-		"16.0.0-alpha.3",
-		"16.0.0-alpha.4",
-		"16.0.0-alpha.5",
-		"16.0.0-alpha.6",
-		"16.0.0-alpha.7",
-		"16.0.0-nightly.20210902",
-		"16.0.0-nightly.20210903",
-		"16.0.0-nightly.20210906",
-		"16.0.0-nightly.20210907",
-		"16.0.0-nightly.20210908",
-		"16.0.0-nightly.20210909",
-		"16.0.0-nightly.20210910",
-		"16.0.0-nightly.20210913",
-		"16.0.0-nightly.20210914",
-		"16.0.0-nightly.20210915",
-		"16.0.0-nightly.20210916",
-		"16.0.0-nightly.20210917",
-		"16.0.0-nightly.20210920",
-		"16.0.0-nightly.20210921",
-		"16.0.0-nightly.20210922",
-		"17.0.0-nightly.20210923",
-		"17.0.0-nightly.20210924",
-		"17.0.0-nightly.20210927",
-		"17.0.0-nightly.20210928",
-		"17.0.0-nightly.20210929",
-		"17.0.0-nightly.20210930",
-		"17.0.0-nightly.20211001",
-		"17.0.0-nightly.20211004",
-		"17.0.0-nightly.20211005"
-	],
-	"96.0.4647.0": [
-		"16.0.0-alpha.8",
-		"16.0.0-alpha.9",
-		"16.0.0-beta.1",
-		"16.0.0-beta.2",
-		"16.0.0-beta.3",
-		"17.0.0-nightly.20211006",
-		"17.0.0-nightly.20211007",
-		"17.0.0-nightly.20211008",
-		"17.0.0-nightly.20211011",
-		"17.0.0-nightly.20211012",
-		"17.0.0-nightly.20211013",
-		"17.0.0-nightly.20211014",
-		"17.0.0-nightly.20211015",
-		"17.0.0-nightly.20211018",
-		"17.0.0-nightly.20211019",
-		"17.0.0-nightly.20211020",
-		"17.0.0-nightly.20211021"
-	],
-	"96.0.4664.18": [
-		"16.0.0-beta.4",
-		"16.0.0-beta.5"
-	],
-	"96.0.4664.27": [
-		"16.0.0-beta.6",
-		"16.0.0-beta.7"
-	],
-	"96.0.4664.35": [
-		"16.0.0-beta.8",
-		"16.0.0-beta.9"
-	],
-	"95.0.4612.5": [
-		"16.0.0-nightly.20210824",
-		"16.0.0-nightly.20210825",
-		"16.0.0-nightly.20210826",
-		"16.0.0-nightly.20210827",
-		"16.0.0-nightly.20210830",
-		"16.0.0-nightly.20210831",
-		"16.0.0-nightly.20210901"
-	],
-	"96.0.4664.45": [
-		"16.0.0",
-		"16.0.1"
-	],
-	"96.0.4664.55": [
-		"16.0.2",
-		"16.0.3",
-		"16.0.4",
-		"16.0.5"
-	],
-	"96.0.4664.110": [
-		"16.0.6"
-	],
-	"96.0.4664.4": [
-		"17.0.0-alpha.1",
-		"17.0.0-alpha.2",
-		"17.0.0-alpha.3",
-		"17.0.0-nightly.20211022",
-		"17.0.0-nightly.20211025",
-		"17.0.0-nightly.20211026",
-		"17.0.0-nightly.20211027",
-		"17.0.0-nightly.20211028",
-		"17.0.0-nightly.20211029",
-		"17.0.0-nightly.20211101",
-		"17.0.0-nightly.20211102",
-		"17.0.0-nightly.20211103",
-		"17.0.0-nightly.20211104",
-		"17.0.0-nightly.20211105",
-		"17.0.0-nightly.20211108",
-		"17.0.0-nightly.20211109",
-		"17.0.0-nightly.20211110",
-		"17.0.0-nightly.20211111",
-		"17.0.0-nightly.20211112",
-		"17.0.0-nightly.20211115",
-		"17.0.0-nightly.20211116",
-		"17.0.0-nightly.20211117",
-		"18.0.0-nightly.20211118",
-		"18.0.0-nightly.20211119",
-		"18.0.0-nightly.20211122",
-		"18.0.0-nightly.20211123"
-	],
-	"98.0.4706.0": [
-		"17.0.0-alpha.4",
-		"17.0.0-alpha.5",
-		"17.0.0-alpha.6",
-		"18.0.0-nightly.20211124",
-		"18.0.0-nightly.20211125",
-		"18.0.0-nightly.20211126",
-		"18.0.0-nightly.20211129",
-		"18.0.0-nightly.20211130",
-		"18.0.0-nightly.20211201",
-		"18.0.0-nightly.20211202",
-		"18.0.0-nightly.20211203",
-		"18.0.0-nightly.20211206",
-		"18.0.0-nightly.20211207",
-		"18.0.0-nightly.20211208",
-		"18.0.0-nightly.20211209",
-		"18.0.0-nightly.20211210",
-		"18.0.0-nightly.20211213",
-		"18.0.0-nightly.20211214",
-		"18.0.0-nightly.20211215",
-		"18.0.0-nightly.20211216",
-		"18.0.0-nightly.20211217",
-		"18.0.0-nightly.20211220",
-		"18.0.0-nightly.20211221",
-		"18.0.0-nightly.20211222",
-		"18.0.0-nightly.20211223",
-		"18.0.0-nightly.20211228",
-		"18.0.0-nightly.20211229",
-		"18.0.0-nightly.20211231",
-		"18.0.0-nightly.20220103",
-		"18.0.0-nightly.20220104",
-		"18.0.0-nightly.20220105"
 	]
 };
\ No newline at end of file
